@@ -1,8 +1,19 @@
 # -*- coding: ISO-8859-1 -*-
-#############################################
-## (C)opyright by Dirk Holtwick, 2002-2007 ##
-## All rights reserved                     ##
-#############################################
+
+# Copyright 2010 Dirk Holtwick, holtwick.it
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 
 __reversion__ = "$Revision: 20 $"
 __author__ = "$Author: holtwick $"
@@ -341,6 +352,17 @@ def getAlign(value, default=TA_LEFT):
 #    # Unused
 #    return str(value).upper()
 
+GAE = "google.appengine" in sys.modules
+
+if GAE:
+    STRATEGIES = (
+        StringIO.StringIO,
+        StringIO.StringIO)
+else:
+    STRATEGIES = (
+        StringIO.StringIO,
+        tempfile.NamedTemporaryFile)
+
 class pisaTempFile(object): 
     """A temporary file implementation that uses memory unless 
     either capacity is breached or fileno is requested, at which 
@@ -353,9 +375,7 @@ class pisaTempFile(object):
     http://code.activestate.com/recipes/496744/
     """ 
 
-    STRATEGIES = (
-        StringIO.StringIO,
-        tempfile.NamedTemporaryFile)
+    STRATEGIES = STRATEGIES
      
     CAPACITY = 10 * 1024
     
@@ -365,11 +385,16 @@ class pisaTempFile(object):
         file gets larger than that size.  Otherwise, the data is stored 
         in memory. 
         """ 
+        
         #if hasattr(buffer, "read"):
         #shutil.copyfileobj(    fsrc, fdst[, length])   
         self.capacity = capacity 
         self.strategy = int(len(buffer) > self.capacity)
-        self._delegate = self.STRATEGIES[self.strategy]() 
+        try:
+            self._delegate = self.STRATEGIES[self.strategy]()
+        except: 
+            # Fallback for Google AppEnginge etc.
+            self._delegate = self.STRATEGIES[0]() 
         self.write(buffer) 
     
     def makeTempFile(self):
